@@ -32,6 +32,7 @@ from .types.reservation import (
     DeleteAssignmentRequest,
     DeleteCapacityCommitmentRequest,
     DeleteReservationRequest,
+    Edition,
     GetBiReservationRequest,
     GetCapacityCommitmentRequest,
     GetReservationRequest,
@@ -68,6 +69,7 @@ __all__ = (
     "DeleteAssignmentRequest",
     "DeleteCapacityCommitmentRequest",
     "DeleteReservationRequest",
+    "Edition",
     "GetBiReservationRequest",
     "GetCapacityCommitmentRequest",
     "GetReservationRequest",
